@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -16,17 +16,12 @@
 
 import re
 import sys
-import os
 from os import path
 import time
 import datetime
-import xml
 import functools
 import bz2
 
-if hasattr(xml,"use_pyxml"):
-    xml.use_pyxml()
-from xml import xpath
 import xml.etree.ElementTree as ET
 import pexpect
 from calculate.lib.configparser import ConfigParser
@@ -42,88 +37,98 @@ from contextlib import closing
 from files import listDirectory, readFile
 from functools import total_ordering
 from itertools import ifilter, imap, chain
-from git import Git, GitError
+
 Colors = TextState.Colors
 import glob
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_lib3',sys.modules[__name__])
+
+setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 reVerSplit = re.compile(r"^(?:.*/var/db/pkg/)?(?:(\w+-\w+)/)?(.*?)-(([^-]+?)"
-                         "(?:-(r\d+))?)(?:.(tbz2))?$",re.S)
+                        "(?:-(r\d+))?)(?:.(tbz2))?$", re.S)
+
 def reVerSplitToPV(x):
     """Convert match from reVerSplit to PV hash"""
     if type(x) in (str, unicode):
         x = reVerSplit.search(x)
     if x:
         match = x.groups()
-        return {'CATEGORY':match[0] or "",
-                'PN':match[1],
-                'PF':"%s-%s"%(match[1],match[2]),
-                'P':"%s-%s"%(match[1],match[3]),
-                'PV':match[3],
-                'PR':match[4] or "r0",
-                'PVR':match[2]}
-    return {'PN':"",
-            'PF':"",
-            'P':"",
-            'PV':"",
-            'PR':"",
-            'PVR':""}.copy()
+        return {'CATEGORY': match[0] or "",
+                'PN': match[1],
+                'PF': "%s-%s" % (match[1], match[2]),
+                'P': "%s-%s" % (match[1], match[3]),
+                'PV': match[3],
+                'PR': match[4] or "r0",
+                'PVR': match[2]}
+    return {'PN': "",
+            'PF': "",
+            'P': "",
+            'PV': "",
+            'PR': "",
+            'PVR': ""}.copy()
+
 
 def getPkgUses(fullpkg, version=None, prefix="/"):
     """Get USE and IUSE from package"""
-    category,slash,pkg = fullpkg.partition('/')
-    pkgCategory = 'var/db/pkg/{0}'.format(category)
-    pkgCategory = path.join(prefix, pkgCategory)
+    category, slash, pkg = fullpkg.partition('/')
+    _pkgCategory = 'var/db/pkg/{0}'.format(category)
+    pkgCategory = path.join(prefix, _pkgCategory)
     if version is None:
-        packages = filter(lambda x:x['PN'] == pkg,
-                   map(reVerSplitToPV,
-                   filter(lambda x:x,
-                   map(lambda x:reVerSplit.search(x),
-                   listDirectory(pkgCategory)))))
+        packages = filter(lambda x: x['PN'] == pkg,
+                          map(reVerSplitToPV,
+                              filter(lambda x: x,
+                                     map(lambda x: reVerSplit.search(x),
+                                         listDirectory(pkgCategory)))))
         if not packages:
             return None
-        usePath = path.join(pkgCategory,packages[-1]['PF'],"USE")
-        iusePath = path.join(pkgCategory,packages[-1]['PF'],"IUSE")
+        usePath = path.join(pkgCategory, packages[-1]['PF'], "USE")
+        iusePath = path.join(pkgCategory, packages[-1]['PF'], "IUSE")
     else:
-        usePath = path.join(pkgCategory, "%s-%s"%(pkg,version),"USE")
-        iusePath = path.join(pkgCategory, "%s-%s"%(pkg,version),"IUSE")
+        usePath = path.join(pkgCategory, "%s-%s" % (pkg, version), "USE")
+        iusePath = path.join(pkgCategory, "%s-%s" % (pkg, version), "IUSE")
     iuse = readFile(iusePath).strip().split()
     use = readFile(usePath).strip().split()
-    return (map(lambda x:x[1:] if x.startswith("+") else x,
-            filter(lambda x:x,
-            use)),
-            map(lambda x:x[1:] if x.startswith("+") else x,
-            filter(lambda x:x,
-            iuse)))
+    return (map(lambda x: x[1:] if x.startswith("+") else x,
+                filter(lambda x: x,
+                       use)),
+            map(lambda x: x[1:] if x.startswith("+") else x,
+                filter(lambda x: x,
+                       iuse)))
 
-def isPkgInstalled(pkg,prefix='/',sortByVersion=False):
+
+def isPkgInstalled(pkg, prefix='/', sortByVersion=False):
     """Check is package installed"""
-    pkgDir = path.join(prefix,'var/db/pkg')
+    pkgDir = path.join(prefix, 'var/db/pkg')
     if "/" in pkg:
-        category,op,pkg = pkg.partition('/')
-        res = map(lambda x:x.update({'CATEGORY':category}) or x,
-                   filter(lambda x:x['PN'] == pkg,
-                   map(reVerSplitToPV,
-                   listDirectory(path.join(pkgDir,category)))))
-        if len(res)>1 and sortByVersion:
-            return sorted(res,key=lambda x:getTupleVersion(x['PVR']))
+        category, op, pkgname = pkg.partition('/')
+
+        def package_generator(pkg_dn):
+            for dn in listDirectory(pkg_dn, fullPath=True):
+                pkg_info = reVerSplitToPV(dn)
+                if pkg_info['PN'] == pkgname:
+                    pkg_info.update({'CATEGORY': category})
+                    yield pkg_info
+        res = list(package_generator(path.join(pkgDir, category)))
+        if len(res) > 1 and sortByVersion:
+            return sorted(res, key=lambda x: getTupleVersion(x['PVR']))
         else:
             return res
     else:
-        return filter(lambda x: filter(lambda y:y['PN'] == pkg,
-                                map(reVerSplitToPV,
-                                listDirectory(x))),
-               listDirectory(pkgDir,fullPath=True))
+        return filter(lambda x: filter(lambda y: y['PN'] == pkg,
+                                       map(reVerSplitToPV,
+                                           listDirectory(x))),
+                      listDirectory(pkgDir, fullPath=True))
 
-def getPkgSlot(pkg,prefix='/'):
+
+def getPkgSlot(pkg, prefix='/'):
     """Get package slot"""
-    pkgs = isPkgInstalled(pkg,prefix)
-    pkgDir = path.join(prefix,'var/db/pkg')
-    return map(lambda x:readFile(path.join(pkgDir,x['CATEGORY'],
-                                           x['PF'],"SLOT")).strip(),
-           pkgs)
+    pkgs = isPkgInstalled(pkg, prefix)
+    pkgDir = path.join(prefix, 'var/db/pkg')
+    return [readFile(path.join(pkgDir, x['CATEGORY'],
+                               x['PF'], "SLOT")).strip()
+            for x in pkgs]
+
 
 def getPkgActiveUses(fullpkg):
     """Get active uses from package"""
@@ -132,16 +137,18 @@ def getPkgActiveUses(fullpkg):
         return None
     return list(set(res[0]) & set(res[1]))
 
+
 def getSquashList():
     """Get supprted squashfs compressions method"""
-    wantMethod = set(["lzo","lzma","xz","gzip"])
-    usesSquashFs = getPkgActiveUses("sys-fs/squashfs-tools")
+    wantMethod = {"lzo", "lzma", "xz", "gzip"}
+    squashfs_tools = "sys-fs/squashfs-tools"
+    usesSquashFs = getPkgActiveUses(squashfs_tools)
     if not usesSquashFs:
         return ["gzip"]
     else:
-        pkgInfo = isPkgInstalled('sys-fs/squashfs-tools')
-        if pkgInfo and pkgInfo[0]['PV']:
-            pkgVer = getTupleVersion(pkgInfo[0]['PV'])
+        pkgInfo = isPkgInstalled(squashfs_tools)
+        if pkgInfo and pkgInfo[0].get('PV', None):
+            pkgVer = getTupleVersion(pkgInfo[0].get('PV'))
             gzipVer = getTupleVersion('4.2')
             if pkgVer >= gzipVer:
                 usesSquashFs.append('gzip')
@@ -172,7 +179,7 @@ class RepositorySubstituting(object):
         emerge_config = self.dv.Get('cl_emerge_config')
         if emerge_config and emerge_config.repositories:
             repos = {x.name.encode('utf-8'): x.location.encode('utf-8')
-                     for x in emerge_config.repositories }
+                     for x in emerge_config.repositories}
             r = re.compile("|".join("^%s:" % x for x in repos.keys()))
             self._substitution = (
                 functools.partial(
@@ -180,7 +187,7 @@ class RepositorySubstituting(object):
                         self.system_root, repos.get(
                             args[0].group(0)[:-1], ""))))
         else:
-            self._substitution = lambda x:x
+            self._substitution = lambda x: x
 
     def __call__(self, s):
         if self.has_repos_name(s):
@@ -208,6 +215,7 @@ def searchProfile(dirpath, configname, repository_sub=None):
 
     return list(search(dirpath))
 
+
 class Layman:
     """
     Объект для управления репозиториями Layman
@@ -233,14 +241,14 @@ class Layman:
         config.read(self.laymanconf, encoding="utf-8")
         if not config.has_section(rname):
             config.add_section(rname)
-        for k,v in {'auto-sync': 'Yes',
-                    'layman-type': 'git',
-                    'priority': '50',
-                    'sync-uri':rurl,
-                    'sync-type': 'laymansync',
-                    'location': rpath}.items():
+        for k, v in {'auto-sync': 'Yes',
+                     'layman-type': 'git',
+                     'priority': '50',
+                     'sync-uri': rurl,
+                     'sync-type': 'laymansync',
+                     'location': rpath}.items():
             config.set(rname, k, v)
-        with open(self.laymanconf,'wb') as f:
+        with open(self.laymanconf, 'wb') as f:
             config.write(f)
 
     def _remove_from_laymanconf(self, rname):
@@ -276,14 +284,16 @@ class Layman:
         source.text = rurl
         try:
             from layman.utils import indent
-
+        except ImportError:
+            indent = None
+        if indent:
             indent(root)
-        except ImportError as e:
-            pass
         with open(self.installed, 'w') as f:
             f.write('<?xml version="1.0" encoding="UTF-8"?>\n')
             tree.write(f, encoding="utf-8")
 
+    portdir_param = "PORTDIR_OVERLAY"
+
     def _add_to_makeconf(self, rpath):
         """
         Добавить репозиторий в layman/make.conf
@@ -293,21 +303,21 @@ class Layman:
             repos = match.group(1).strip().split('\n')
             if not rpath in repos:
                 repos.insert(0, rpath)
-            return 'PORTDIR_OVERLAY="\n%s"' % "\n".join(repos);
+            return '%s="\n%s"' % (self.portdir_param, "\n".join(repos))
 
         if path.exists(self.makeconf):
             content = readFile(self.makeconf)
-            if "PORTDIR_OVERLAY" in content:
-                new_content = re.sub("\APORTDIR_OVERLAY=\"([^\"]+)\"",
+            if self.portdir_param in content:
+                new_content = re.sub('\A%s="([^\"]+)"' % self.portdir_param,
                                      fixContent, content, re.DOTALL)
                 if new_content == content:
                     return
                 else:
                     content = new_content
             else:
-                content = 'PORTDIR_OVERLAY="\n%s"\n' % rpath + content
+                content = '%s="\n%s"\n' % (self.portdir_param, rpath + content)
         else:
-            content = 'PORTDIR_OVERLAY="\n%s"\n' % rpath
+            content = '%s="\n%s"\n' % (self.portdir_param, rpath)
         with open(self.makeconf, 'w') as f:
             f.write(content)
 
@@ -315,18 +325,18 @@ class Layman:
         """
         Удалить путь из make.conf
         """
+
         def fixContent(match):
             repos = match.group(1).strip().split('\n')
             if rpath in repos:
                 repos.remove(rpath)
-            return 'PORTDIR_OVERLAY="\n%s"' % "\n".join(repos);
+            return '%s="\n%s"' % (self.portdir_param, "\n".join(repos))
 
         if path.exists(self.makeconf):
             content = readFile(self.makeconf)
-            if "PORTDIR_OVERLAY" in content:
-                new_content = re.sub(
-                    "\APORTDIR_OVERLAY=\"([^\"]+)\"",
-                    fixContent, content, re.DOTALL)
+            if self.portdir_param in content:
+                new_content = re.sub('\A%s="([^\"]+)"' % self.portdir_param,
+                                     fixContent, content, re.DOTALL)
                 if new_content == content:
                     return
                 with open(self.makeconf, 'w') as f:
@@ -338,8 +348,8 @@ class Layman:
         portage_pkg_info = isPkgInstalled(self.portage_package,
                                           prefix=self.prefix.encode('utf-8'))
         if layman_pkg_info and portage_pkg_info:
-            layman_ver = layman_pkg_info[0]['PV']
-            portage_ver = portage_pkg_info[0]['PV']
+            layman_ver = layman_pkg_info[0].get('PV')
+            portage_ver = portage_pkg_info[0].get('PV')
             if (cmpVersion(layman_ver, "2.3") >= 0 and
                         cmpVersion(portage_ver, "2.2.18") >= 0):
                 return True
@@ -368,9 +378,10 @@ class Layman:
                 root.remove(el)
                 try:
                     from layman.utils import indent
+                except ImportError:
+                    indent = None
+                if indent:
                     indent(root)
-                except ImportError as e:
-                    pass
                 with open(self.installed, 'w') as f:
                     f.write('<?xml version="1.0" encoding="UTF-8"?>\n')
                     tree.write(f, encoding="utf-8")
@@ -535,9 +546,9 @@ class PackageInformation:
                                    timeout=60).read()
         except pexpect.TIMEOUT:
             output = ""
-        re_cut = re.compile("^.*?(?=<\?xml version)",re.S)
+        re_cut = re.compile("^.*?(?=<\?xml version)", re.S)
         with ignore(ET.ParseError):
-            xml = ET.fromstring(re_cut.sub('',output))
+            xml = ET.fromstring(re_cut.sub('', output))
             for pkg in self.query_packages:
                 cat_pn = pkg['CATEGORY/PN']
                 if not cat_pn in self.information_cache:
@@ -555,11 +566,12 @@ class PackageInformation:
         pkg.info = cls(pkg)
         return pkg
 
+
 class UnmergePackage(EmergePackage):
     """
     Информация об обновлении одного пакета
     """
-    re_pkg_info = re.compile("^\s(\S+)\n\s+selected:\s(\S+)",re.MULTILINE)
+    re_pkg_info = re.compile("^\s(\S+)\n\s+selected:\s(\S+)", re.MULTILINE)
 
     def __init__(self, package):
         super(UnmergePackage, self).__init__(package)
@@ -587,6 +599,7 @@ def recalculate_update_info(cls):
             pkg_size=cls.pkg_size), re.MULTILINE)
     return cls
 
+
 @recalculate_update_info
 @total_ordering
 class EmergeUpdateInfo(Mapping):
@@ -664,6 +677,7 @@ class EmergeUpdateInfo(Mapping):
     def __str__(self):
         return "%s/%s" % (self['CATEGORY'], self['PF'])
 
+
 @recalculate_update_info
 class EmergeRemoveInfo(EmergeUpdateInfo):
     """
@@ -682,13 +696,12 @@ class Eix(object):
     """
     cmd = getProgPath("/usr/bin/eix")
 
-    class Option:
+    class Option(object):
         Installed = '--installed'
         Xml = '--xml'
         Upgrade = '--upgrade'
         TestObsolete = '--test-obsolete'
 
-
     default_options = [Option.Xml]
 
     def __init__(self, package, *options, **kwargs):
@@ -748,6 +761,7 @@ class Eix(object):
         except ET.ParseError:
             return iter(())
 
+
 class ChrootEix(Eix):
     """
     Eix выполняемый в chroot
@@ -810,14 +824,15 @@ class EmergeLogNamedTask(EmergeLogTask):
         """
         return " *** Calculate: Finished %s" % self.taskname
 
-class EmergeLogPackageTask(EmergeLogTask):
 
+class EmergeLogPackageTask(EmergeLogTask):
     def has_marker(self, line):
         """
         Определить есть ли в строке маркер завершения сборки пакета
         """
         return ") Merging " in line
 
+
 class EmergeLog:
     """
     EmergeLog(after).get_update(package_pattern)
@@ -874,12 +889,12 @@ class EmergeLog:
         """
         self._list, self._remove_list = \
             zip(*self._parse_log(self._get_last_changes()))
-        self._list = filter(None,self._list)
+        self._list = filter(None, self._list)
         self._remove_list = filter(None, self._remove_list)
 
     def _parse_log(self, data):
-        searcher = lambda x:(self.re_complete_emerge.search(x) or
-                            self.re_complete_unmerge.search(x))
+        searcher = lambda x: (self.re_complete_emerge.search(x) or
+                              self.re_complete_unmerge.search(x))
         for re_match in ifilter(None, imap(searcher, data)):
             if re_match.group(1) == "emerge":
                 yield re_match.group(2), None
@@ -920,9 +935,9 @@ class PackageList(object):
     def _packages(self):
         if self.result is None:
             self.result = filter(lambda x: x['PN'],
-                                  imap(lambda x: (x if isinstance(x, Mapping)
-                                                  else EmergePackage(x)),
-                                       self._raw_list))
+                                 imap(lambda x: (x if isinstance(x, Mapping)
+                                                 else EmergePackage(x)),
+                                      self._raw_list))
         return self.result
 
     def __getitem__(self, item):
@@ -949,16 +964,12 @@ class PackageList(object):
         return any(pkg >= other for pkg in self._packages())
 
     def __eq__(self, other):
-        for pkg in self._packages():
-            if pkg == other:
-                return True
-        else:
-            return False
         return any(pkg == other for pkg in self._packages())
 
     def __ne__(self, other):
         return any(pkg != other for pkg in self._packages())
 
+
 class Manifest:
     """
     Объект используется для получения данных из Manifest
@@ -968,52 +979,59 @@ class Manifest:
 
     def __init__(self, manifest):
         self._manifest = manifest
-    
+
     def get_dist_files(self):
         """
         Получить список файлов из Manifest
         """
-        return imap(lambda x:x.group(1),
-            ifilter(None,
-            imap(self.re_dist.search,
-            readLinesFile(self._manifest))))
+        return imap(lambda x: x.group(1),
+                    ifilter(None,
+                            imap(self.re_dist.search,
+                                 readLinesFile(self._manifest))))
+
 
 class Ebuild:
     """
     Объект используемый для получения данных из ebuild файлов
     """
+
     def __init__(self, ebuild):
         self._ebuild = ebuild
         self._category = path.basename(
-                         path.dirname(
-                         path.dirname(ebuild)))
+            path.dirname(
+                path.dirname(ebuild)))
         self._pkgname = path.basename(self._ebuild)[:-7]
 
     def get_tbz2(self):
         """
         Получить имя бинарного пакета с каталогом категории
         """
-        return "%s/%s.tbz2"%(self._category, self._pkgname)
+        return "%s/%s.tbz2" % (self._category, self._pkgname)
+
 
 def get_packages_files_directory(*directories):
     """
-    Получить список бинарных пакетов по ebuild файлам находящихся в директории (sys-apps/portage-2.2.0.tbz2)
+    Получить список бинарных пакетов по ebuild файлам находящихся в директории
+    (sys-apps/portage-2.2.0.tbz2)
     """
     for directory in directories:
         directory = path.normpath(directory)
-        for ebuild in glob.glob("%s/*/*/*.ebuild"%directory):
+        for ebuild in glob.glob("%s/*/*/*.ebuild" % directory):
             yield Ebuild(ebuild).get_tbz2()
 
+
 def get_manifest_files_directory(*directories):
     """
-    Получить список файлов из всех Manifest находящихся в директориях и поддиректориях (portage-2.2.0.tar.bz2)
+    Получить список файлов из всех Manifest находящихся в директориях
+    и поддиректориях (portage-2.2.0.tar.bz2)
     """
     for directory in directories:
         directory = path.normpath(directory)
-        for manifest in glob.glob("%s/*/*/Manifest"%directory):
+        for manifest in glob.glob("%s/*/*/Manifest" % directory):
             for fn in Manifest(manifest).get_dist_files():
                 yield fn
 
+
 def get_remove_list(directory, filelist, depth=1):
     """
     Получить все файлы из директории, которых нет в filelist
@@ -1021,14 +1039,15 @@ def get_remove_list(directory, filelist, depth=1):
     директорией
     """
     directory = path.normpath(directory)
-    l = len(directory)+1
-    for fn in ifilter(lambda x:not x[l:] in filelist,
-              find(directory,
-              onefilesystem=True,
-              fullpath=True, depth=depth)):
+    l = len(directory) + 1
+    for fn in ifilter(lambda x: not x[l:] in filelist,
+                      find(directory,
+                           onefilesystem=True,
+                           fullpath=True, depth=depth)):
         if path.isfile(fn):
             yield fn
 
+
 class SimpleRepositoryMapper(Mapping):
     """
     Определение пути до репозитория
@@ -1088,7 +1107,7 @@ class EbuildInfo(object):
     def __ne__(self, other):
         res = any(other[k] != self[k] for k in self.support_keys)
         # TODO: DEBUG
-        #if res:
+        # if res:
         #    for k in self.support_keys:
         #        if other[k] != self[k]:
         #            print k,":", other[k], "!=", self[k]
