@@ -517,6 +517,19 @@ class VariableOsLocaleXkbname(ReadonlyVariable, Locale):
             return locale_xkb.split("(")[0]
         return ""
 
+class VariableOsLocaleLatSet(ReadonlyVariable, Locale):
+    """
+    Локаль содержит раскладку совместимую с латиницей
+
+    Используется для отображения индикатора переключения языка
+    """
+    def get(self):
+        """xkb layouts (example: en,ru)"""
+        layout = self.Get('os_locale_xkbname').split(',')
+        if layout == 1:
+            return "on"
+        else:
+            return "off"
 
 class VariableOsLang(ReadonlyVariable, Locale):
     """
